|Documentation|_ |License|_ |DOI10.3390/e2203029|_

.. |Documentation| image:: https://readthedocs.org/projects/elpigraph-python/badge/?version=latest
.. _Documentation: https://elpigraph-python.readthedocs.io
.. |License| image:: https://img.shields.io/github/license/j-bac/elpigraph-python.svg
.. _License: https://github.com/j-bac/elpigraph-python/blob/master/LICENSE
.. |DOI10.3390/e2203029| image:: https://img.shields.io/badge/DOI-10.3390%2Fe22030296-blue
..  _DOI10.3390/e2203029: https://doi.org/10.3390/e22030296

elpigraph-python - Principal elastic graphs in Python
=====================================================

**elpigraph-python** is a Python module to fit principal graphs to data.

What are principal graphs ?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Principal graph algorithms fit a graph that passes in the middle of the data point cloud.

Organization of `elpigraph-python`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

`elpigraph-python` provides principal graph functions directly in the main module, and two submodules `plot` and `utils` contain utility functions.

Support
^^^^^^^
Feel free to report an `issue <https://github.com/j-bac/elpigraph-python/issues/new/choose>`_

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Main

   installation
   quick_start
   api
   release_notes
   references
   contributing

.. toctree::
   :caption: Tutorials
   :maxdepth: 1
   :hidden:

   basics
   graph_editing